@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK::Rule;
 
-$BankAccount::Validator::UK::Rule::VERSION   = '0.65';
+$BankAccount::Validator::UK::Rule::VERSION   = '0.66';
 $BankAccount::Validator::UK::Rule::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK::Rule - Rules for validating UK bank account.
 
 =head1 VERSION
 
-Version 0.65
+Version 0.66
 
 =cut
 
@@ -112,7 +112,7 @@ sub _raw_data {
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
@@ -120,8 +120,7 @@ L<https://github.com/manwar/BankAccount-Validator-UK>
 
 =head1 BUGS
 
-Please  report any bugs or feature requests to C<bug-bankaccount-validator-uk  at
-rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=BankAccount-Validator-UK>.
+Please  report any bugs or feature requests through the web interface at L<https://github.com/manwar/BankAccount-Validator-UK/issues>.
 I will be notified, and then you'll automatically be notified of progress on your
 bug as I make changes.
 
@@ -135,9 +134,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=BankAccount-Validator-UK>
+L<https://github.com/manwar/BankAccount-Validator-UK/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -147,15 +146,15 @@ L<http://annocpan.org/dist/BankAccount-Validator-UK>
 
 L<http://cpanratings.perl.org/d/BankAccount-Validator-UK>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/BankAccount-Validator-UK/>
+L<https://metacpan.org/dist/BankAccount-Validator-UK>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2012 - 2017 Mohammad S Anwar.
+Copyright (C) 2012 - 2024 Mohammad Sajid Anwar.
 
 This program  is  free software; you can redistribute it and / or modify it under
 the  terms  of the the Artistic  License (2.0). You may obtain a copy of the full
